@@ -9,6 +9,11 @@ use warnings;
 
 Promise::ES6::Mojo - L<Promises/A+-compliant|https://github.com/promises-aplus/promises-spec> promises for L<Mojolicious>
 
+=head1 DEPRECATION NOTICE
+
+This module is deprecated and will go away eventually.
+Use C<use_event()> instead, as described in L<Promise::ES6>’s documentation.
+
 =head1 DESCRIPTION
 
 This module exposes the same functionality as L<Promise::ES6::AnyEvent>
